# API Reference

## Classes

```{eval-rst}
.. currentmodule:: ess.nmx

.. autosummary::
   :toctree: ../generated/classes
   :template: class-template.rst
   :recursive:

   NMXData
   NMXReducedData
   InputFilepath
   TimeBinSteps

```

## Top-level functions

```{eval-rst}
.. autosummary::
   :toctree: ../generated/functions
   :recursive:

   small_mcstas_3_sample
   load_mcstas_nexus

```

## Submodules

```{eval-rst}
.. autosummary::
   :toctree: ../generated/modules
   :template: module-template.rst
   :recursive:

   data
   mcstas_loader

```
